summaryrefslogtreecommitdiff
path: root/vendor/github.com
diff options
context:
space:
mode:
authorDaniel J Walsh <dwalsh@redhat.com>2021-05-20 09:51:36 -0400
committerDaniel J Walsh <dwalsh@redhat.com>2021-05-20 09:51:36 -0400
commitc553181fd07e186639aee50a16426cc5205496e0 (patch)
tree7773d833e33e62174f0a3f79a12d7f7f23ddeee1 /vendor/github.com
parent7bcec8697fc877345de6220d2766ebe36e7158aa (diff)
downloadpodman-c553181fd07e186639aee50a16426cc5205496e0.tar.gz
podman-c553181fd07e186639aee50a16426cc5205496e0.tar.bz2
podman-c553181fd07e186639aee50a16426cc5205496e0.zip
Vendor in containers/buildah v1.21.0
Signed-off-by: Daniel J Walsh <dwalsh@redhat.com>
Diffstat (limited to 'vendor/github.com')
-rw-r--r--vendor/github.com/containers/buildah/CHANGELOG.md219
-rw-r--r--vendor/github.com/containers/buildah/changelog.txt82
-rw-r--r--vendor/github.com/containers/buildah/define/types.go2
-rw-r--r--vendor/github.com/containers/buildah/go.mod2
-rw-r--r--vendor/github.com/containers/buildah/go.sum4
-rw-r--r--vendor/github.com/containers/buildah/imagebuildah/build.go20
6 files changed, 313 insertions, 16 deletions
diff --git a/vendor/github.com/containers/buildah/CHANGELOG.md b/vendor/github.com/containers/buildah/CHANGELOG.md
index 25f02db19..7a0af9298 100644
--- a/vendor/github.com/containers/buildah/CHANGELOG.md
+++ b/vendor/github.com/containers/buildah/CHANGELOG.md
@@ -1,6 +1,225 @@
![buildah logo](https://cdn.rawgit.com/containers/buildah/master/logos/buildah-logo_large.png)
# Changelog
+## v1.21.0 (2021-05-19)
+ Don't blow up if cpp detects errors
+ Vendor in containers/common v0.38.4
+ Remove 'buildah run --security-opt' from completion
+ update c/common
+ Fix handling of --default-mounts-file
+ update vendor of containers/storage v1.31.1
+ Bump github.com/containers/storage from 1.30.3 to 1.31.0
+ Send logrus messages back to caller when building
+ github: Fix bad repo. ref in workflow config
+ Check earlier for bad image tags name
+ buildah bud: fix containers/podman/issues/10307
+ Bump github.com/containers/storage from 1.30.1 to 1.30.3
+ Cirrus: Support [CI:DOCS] test skipping
+ Notification email for cirrus-cron build failures
+ Bump github.com/opencontainers/runc from 1.0.0-rc93 to 1.0.0-rc94
+ Fix race condition
+ Fix copy race while walking paths
+ Preserve ownership of lower directory when doing an overlay mount
+ Bump github.com/onsi/gomega from 1.11.0 to 1.12.0
+ Update nix pin with `make nixpkgs`
+ codespell cleanup
+ Multi-arch github-action workflow unification
+ Bump github.com/containers/image/v5 from 5.11.1 to 5.12.0
+ Bump github.com/onsi/ginkgo from 1.16.1 to 1.16.2
+ imagebuildah: ignore signatures when tagging images
+ update to latest libimage
+ Bump github.com/containers/common from 0.37.0 to 0.37.1
+ Bump github.com/containers/storage from 1.30.0 to 1.30.1
+ Upgrade to GitHub-native Dependabot
+ Document location of auth.json file if XDG_RUNTIME_DIR is not set
+ run.bats: fix flake in run-user test
+ Cirrus: Update F34beta -> F34
+ pr-should-include-tests: try to make work in buildah
+ runUsingRuntime: when relaying error from the runtime, mention that
+ Run(): avoid Mkdir() into the rootfs
+ imagebuildah: replace archive with chrootarchive
+ imagebuildah.StageExecutor.volumeCacheSaveVFS(): set up bind mounts
+ conformance: use :Z with transient mounts when SELinux is enabled
+ bud.bats: fix a bats warning
+ imagebuildah: create volume directories when using overlays
+ imagebuildah: drop resolveSymlink()
+ namespaces test - refactoring and cleanup
+ Refactor 'idmapping' system test
+ Cirrus: Update Ubuntu images to 21.04
+ Tiny fixes in bud system tests
+ Add compabitility wrappers for removed packages
+ Fix expected message at pulling image
+ Fix system tests of 'bud' subcommand
+ [CI:DOCS] Update steps for CentOS runc users
+ Add support for secret mounts
+ Add buildah manifest rm command
+ restore push/pull and util API
+ [CI:DOCS] Remove older distro docs
+ Rename rhel secrets to subscriptions
+ vendor in openshift/imagebuilder
+ Remove buildah bud --loglevel ...
+ use new containers/common/libimage package
+ Fix copier when using globs
+ Test namespace flags of 'bud' subcommand
+ Add system test of 'bud' subcommand
+ Output names of multiple tags in buildah bud
+ push to docker test: don't get fooled by podman
+ copier: add Remove()
+ build(deps): bump github.com/containers/image/v5 from 5.10.5 to 5.11.1
+ Restore log timestamps
+ Add system test of 'buildah help' with a tiny fix
+ tests: copy.bats: fix infinite hang
+ Do not force hard code to crun in rootless mode
+ build(deps): bump github.com/openshift/imagebuilder from 1.2.0 to 1.2.1
+ build(deps): bump github.com/containers/ocicrypt from 1.1.0 to 1.1.1
+ build(deps): bump github.com/containers/common from 0.35.4 to 0.36.0
+ Fix arg missing warning in bud
+ Check without flag in 'from --cgroup-parent' test
+ Minor fixes to Buildah as a library tutorial documentation
+ Add system test of 'buildah version' for packaged buildah
+ Add a few system tests of 'buildah from'
+ Log the final error with %+v at logging level "trace"
+ copier: add GetOptions.NoCrossDevice
+ Update nix pin with `make nixpkgs`
+ Bump to v1.20.2-dev
+
+## v1.20.1 (2021-04-13)
+ Run container with isolation type set at 'from'
+ bats helpers.bash - minor refactoring
+ Bump containers/storage vendor to v1.29.0
+ build(deps): bump github.com/onsi/ginkgo from 1.16.0 to 1.16.1
+ Cirrus: Update VMs w/ F34beta
+ CLI add/copy: add a --from option
+ build(deps): bump github.com/onsi/ginkgo from 1.15.2 to 1.16.0
+ Add authentication system tests for 'commit' and 'bud'
+ fix local image lookup for custom platform
+ Double-check existence of OCI runtimes
+ Cirrus: Make use of shared get_ci_vm container
+ Add system tests of "buildah run"
+ Update nix pin with `make nixpkgs`
+ Remove some stuttering on returns errors
+ Setup alias for --tty to --terminal
+ Add conformance tests for COPY /...
+ Put a few more minutes on the clock for the CI conformance test
+ Add a conformance test for COPY --from $symlink
+ Add conformance tests for COPY ""
+ Check for symlink in builtin volume
+ Sort all mounts by destination directory
+ System-test cleanup
+ Export parse.Platform string to be used by podman-remote
+ blobcache: fix sequencing error
+ build(deps): bump github.com/containers/common from 0.35.3 to 0.35.4
+ Fix URL in demos/buildah_multi_stage.sh
+ Add a few system tests
+ [NO TESTS NEEDED] Use --recurse-modules when building git context
+ Bump to v1.20.1-dev
+
+## v1.20.0 (2021-03-25)
+ * vendor in containers/storage v1.28.1
+ * build(deps): bump github.com/containers/common from 0.35.2 to 0.35.3
+ * tests: prefetch: use buildah, not podman, for pulls
+ * Use faster way to check image tag existence during multi-arch build
+ * Add information about multi-arch images to the Readme
+ * COPY --chown: expand the conformance test
+ * pkg/chrootuser: use a bufio.Scanner
+ * [CI:DOCS] Fix rootful typo in docs
+ * build(deps): bump github.com/onsi/ginkgo from 1.15.1 to 1.15.2
+ * Add documentation and testing for .containerignore
+ * build(deps): bump github.com/sirupsen/logrus from 1.8.0 to 1.8.1
+ * build(deps): bump github.com/hashicorp/go-multierror from 1.1.0 to 1.1.1
+ * Lookup Containerfile if user specifies a directory
+ * Add Tag format placeholder to docs
+ * copier: ignore sockets
+ * image: propagate errors from extractRootfs
+ * Remove system test of 'buildah containers -a'
+ * Clarify userns options are usable only as root in man pages
+ * Fix system test of 'containers -a'
+ * Remove duplicated code in addcopy
+ * build(deps): bump github.com/onsi/ginkgo from 1.15.0 to 1.15.1
+ * build(deps): bump github.com/onsi/gomega from 1.10.5 to 1.11.0
+ * build(deps): bump github.com/fsouza/go-dockerclient from 1.7.1 to 1.7.2
+ * Update multi-arch buildah build setup with new logic
+ * Update nix pin with `make nixpkgs`
+ * overlay.bats: fix the "overlay source permissions" test
+ * imagebuildah: use overlay for volumes when using overlay
+ * Make PolicyMap and PullPolicy names align
+ * copier: add GetOptions.IgnoreUnreadable
+ * Check local image to match system context
+ * fix: Containerfiles - smaller set of userns u/gids
+ * Set upperdir permissions based on source
+ * Shrink the vendoring size of pkc/cli
+ * Clarify image name match failure message
+ * ADD/COPY: create the destination directory first, chroot to it
+ * copier.GetOptions: add NoDerefSymLinks
+ * copier: add an Eval function
+ * Update system test for 'from --cap-add/drop'
+ * copier: fix a renaming bug
+ * copier: return child process stderr if we can't JSON decode the response
+ * Add some system tests
+ * build(deps): bump github.com/containers/storage from 1.26.0 to 1.27.0
+ * complement add/copy --chmod documentation
+ * buildah login and logout, do not need to enter user namespace
+ * Add multi-arch image build
+ * chmod/chown added/fixed in bash completions
+ * OWNERS: add @lsm5
+ * buildah add/copy --chmod dockerfile implementation
+ * bump github.com/openshift/imagebuilder from 1.1.8 to 1.2.0
+ * buildah add/copy --chmod cli implementation for files and urls
+ * Make sure we set the buildah version label
+ * Isolation strings, should match user input
+ * [CI:DOCS] buildah-from.md: remove dup arch,os
+ * build(deps): bump github.com/containers/image/v5 from 5.10.2 to 5.10.3
+ * Cirrus: Temp. disable prior-fedora (F32) testing
+ * pr-should-include-tests: recognized "renamed" tests
+ * build(deps): bump github.com/sirupsen/logrus from 1.7.0 to 1.8.0
+ * build(deps): bump github.com/fsouza/go-dockerclient from 1.7.0 to 1.7.1
+ * build(deps): bump github.com/containers/common from 0.34.2 to 0.35.0
+ * Fix reaping of stages with no instructions
+ * add stale bot
+ * Add base image name to comment
+ * build(deps): bump github.com/spf13/cobra from 1.1.1 to 1.1.3
+ * Don't fail copy to emptydir
+ * buildah: use volatile containers
+ * vendor: update containers/storage
+ * Eliminate the use of containers/building import in pkg subdirs
+ * Add more support for removing config
+ * Improve messages about --cache-from not being supported
+ * Revert patch to allow COPY/ADD of empty dirs.
+ * Don't fail copy to emptydir
+ * Fix tutorial for rootless mode
+ * Fix caching layers with build args
+ * Vendor in containers/image v5.10.2
+ * build(deps): bump github.com/containers/common from 0.34.0 to 0.34.2
+ * build(deps): bump github.com/onsi/ginkgo from 1.14.2 to 1.15.0
+ * 'make validate': require PRs to include tests
+ * build(deps): bump github.com/onsi/gomega from 1.10.4 to 1.10.5
+ * build(deps): bump github.com/containers/storage from 1.24.5 to 1.25.0
+ * Use chown function for U volume flag from containers/common repository
+ * --iidfile: print hash prefix
+ * bump containernetworking/cni to v0.8.1 - fix for CVE-2021-20206
+ * run: fix check for host pid namespace
+ * Finish plumbing for buildah bud --manifest
+ * buildah manifest add localimage should work
+ * Stop testing directory permissions with latest docker
+ * Fix build arg check
+ * build(deps): bump github.com/containers/ocicrypt from 1.0.3 to 1.1.0
+ * [ci:docs] Fix man page for buildah push
+ * Update nix pin with `make nixpkgs`
+ * Bump to containers/image v5.10.1
+ * Rebuild layer if a change in ARG is detected
+ * Bump golang.org/x/crypto to the latest
+ * Add Ashley and Urvashi to Approvers
+ * local image lookup by digest
+ * Use build-arg ENV val from local environment if set
+ * Pick default OCI Runtime from containers.conf
+ * Added required devel packages
+ * Cirrus: Native OSX Build
+ * Cirrus: Two minor cleanup items
+ * Workaround for RHEL gating test failure
+ * build(deps): bump github.com/stretchr/testify from 1.6.1 to 1.7.0
+ * build(deps): bump github.com/mattn/go-shellwords from 1.0.10 to 1.0.11
+ * Reset upstream branch to dev version
+ * If destination does not exists, do not throw error
## v1.19.0 (2021-01-08)
Update vendor of containers/storage and containers/common
diff --git a/vendor/github.com/containers/buildah/changelog.txt b/vendor/github.com/containers/buildah/changelog.txt
index 7d31c854d..3bde05a3e 100644
--- a/vendor/github.com/containers/buildah/changelog.txt
+++ b/vendor/github.com/containers/buildah/changelog.txt
@@ -1,3 +1,85 @@
+- Changelog for v1.21.0 (2021-05-19)
+ * Don't blow up if cpp detects errors
+ * Vendor in containers/common v0.38.4
+ * Remove 'buildah run --security-opt' from completion
+ * update c/common
+ * Fix handling of --default-mounts-file
+ * update vendor of containers/storage v1.31.1
+ * Bump github.com/containers/storage from 1.30.3 to 1.31.0
+ * Send logrus messages back to caller when building
+ * github: Fix bad repo. ref in workflow config
+ * Check earlier for bad image tags name
+ * buildah bud: fix containers/podman/issues/10307
+ * Bump github.com/containers/storage from 1.30.1 to 1.30.3
+ * Cirrus: Support [CI:DOCS] test skipping
+ * Notification email for cirrus-cron build failures
+ * Bump github.com/opencontainers/runc from 1.0.0-rc93 to 1.0.0-rc94
+ * Fix race condition
+ * Fix copy race while walking paths
+ * Preserve ownership of lower directory when doing an overlay mount
+ * Bump github.com/onsi/gomega from 1.11.0 to 1.12.0
+ * Update nix pin with `make nixpkgs`
+ * codespell cleanup
+ * Multi-arch github-action workflow unification
+ * Bump github.com/containers/image/v5 from 5.11.1 to 5.12.0
+ * Bump github.com/onsi/ginkgo from 1.16.1 to 1.16.2
+ * imagebuildah: ignore signatures when tagging images
+ * update to latest libimage
+ * Bump github.com/containers/common from 0.37.0 to 0.37.1
+ * Bump github.com/containers/storage from 1.30.0 to 1.30.1
+ * Upgrade to GitHub-native Dependabot
+ * Document location of auth.json file if XDG_RUNTIME_DIR is not set
+ * run.bats: fix flake in run-user test
+ * Cirrus: Update F34beta -> F34
+ * pr-should-include-tests: try to make work in buildah
+ * runUsingRuntime: when relaying error from the runtime, mention that
+ * Run(): avoid Mkdir() into the rootfs
+ * imagebuildah: replace archive with chrootarchive
+ * imagebuildah.StageExecutor.volumeCacheSaveVFS(): set up bind mounts
+ * conformance: use :Z with transient mounts when SELinux is enabled
+ * bud.bats: fix a bats warning
+ * imagebuildah: create volume directories when using overlays
+ * imagebuildah: drop resolveSymlink()
+ * namespaces test - refactoring and cleanup
+ * Refactor 'idmapping' system test
+ * Cirrus: Update Ubuntu images to 21.04
+ * Tiny fixes in bud system tests
+ * Add compabitility wrappers for removed packages
+ * Fix expected message at pulling image
+ * Fix system tests of 'bud' subcommand
+ * [CI:DOCS] Update steps for CentOS runc users
+ * Add support for secret mounts
+ * Add buildah manifest rm command
+ * restore push/pull and util API
+ * [CI:DOCS] Remove older distro docs
+ * Rename rhel secrets to subscriptions
+ * vendor in openshift/imagebuilder
+ * Remove buildah bud --loglevel ...
+ * use new containers/common/libimage package
+ * Fix copier when using globs
+ * Test namespace flags of 'bud' subcommand
+ * Add system test of 'bud' subcommand
+ * Output names of multiple tags in buildah bud
+ * push to docker test: don't get fooled by podman
+ * copier: add Remove()
+ * build(deps): bump github.com/containers/image/v5 from 5.10.5 to 5.11.1
+ * Restore log timestamps
+ * Add system test of 'buildah help' with a tiny fix
+ * tests: copy.bats: fix infinite hang
+ * Do not force hard code to crun in rootless mode
+ * build(deps): bump github.com/openshift/imagebuilder from 1.2.0 to 1.2.1
+ * build(deps): bump github.com/containers/ocicrypt from 1.1.0 to 1.1.1
+ * build(deps): bump github.com/containers/common from 0.35.4 to 0.36.0
+ * Fix arg missing warning in bud
+ * Check without flag in 'from --cgroup-parent' test
+ * Minor fixes to Buildah as a library tutorial documentation
+ * Add system test of 'buildah version' for packaged buildah
+ * Add a few system tests of 'buildah from'
+ * Log the final error with %+v at logging level "trace"
+ * copier: add GetOptions.NoCrossDevice
+ * Update nix pin with `make nixpkgs`
+ * Bump to v1.20.2-dev
+
- Changelog for v1.20.1 (2021-04-13)
* Run container with isolation type set at 'from'
* bats helpers.bash - minor refactoring
diff --git a/vendor/github.com/containers/buildah/define/types.go b/vendor/github.com/containers/buildah/define/types.go
index 45e85e138..f2327e8df 100644
--- a/vendor/github.com/containers/buildah/define/types.go
+++ b/vendor/github.com/containers/buildah/define/types.go
@@ -28,7 +28,7 @@ const (
Package = "buildah"
// Version for the Package. Bump version in contrib/rpm/buildah.spec
// too.
- Version = "1.20.2-dev"
+ Version = "1.21.0"
// DefaultRuntime if containers.conf fails.
DefaultRuntime = "runc"
diff --git a/vendor/github.com/containers/buildah/go.mod b/vendor/github.com/containers/buildah/go.mod
index 1ff94c922..21575cec2 100644
--- a/vendor/github.com/containers/buildah/go.mod
+++ b/vendor/github.com/containers/buildah/go.mod
@@ -4,7 +4,7 @@ go 1.12
require (
github.com/containernetworking/cni v0.8.1
- github.com/containers/common v0.38.3
+ github.com/containers/common v0.38.4
github.com/containers/image/v5 v5.12.0
github.com/containers/ocicrypt v1.1.1
github.com/containers/storage v1.31.1
diff --git a/vendor/github.com/containers/buildah/go.sum b/vendor/github.com/containers/buildah/go.sum
index 235838b4e..0a09fcd6f 100644
--- a/vendor/github.com/containers/buildah/go.sum
+++ b/vendor/github.com/containers/buildah/go.sum
@@ -201,8 +201,8 @@ github.com/containernetworking/cni v0.8.1 h1:7zpDnQ3T3s4ucOuJ/ZCLrYBxzkg0AELFfII
github.com/containernetworking/cni v0.8.1/go.mod h1:LGwApLUm2FpoOfxTDEeq8T9ipbpZ61X79hmU3w8FmsY=
github.com/containernetworking/plugins v0.8.6/go.mod h1:qnw5mN19D8fIwkqW7oHHYDHVlzhJpcY6TQxn/fUyDDM=
github.com/containernetworking/plugins v0.9.1/go.mod h1:xP/idU2ldlzN6m4p5LmGiwRDjeJr6FLK6vuiUwoH7P8=
-github.com/containers/common v0.38.3 h1:kbdGw+weGFjZLhWd8Gsv+BlaTLx7gYDDS5lh4qc+Lfk=
-github.com/containers/common v0.38.3/go.mod h1:egfpX/Y3+19Dz4Wa1eRZDdgzoEOeneieF9CQppKzLBg=
+github.com/containers/common v0.38.4 h1:WYv4R6Sw1qiOPZtBNbKglrmisXdPcq3fZ3bGy4prrjo=
+github.com/containers/common v0.38.4/go.mod h1:egfpX/Y3+19Dz4Wa1eRZDdgzoEOeneieF9CQppKzLBg=
github.com/containers/image/v5 v5.12.0 h1:1hNS2QkzFQ4lH3GYQLyAXB0acRMhS1Ubm6oV++8vw4w=
github.com/containers/image/v5 v5.12.0/go.mod h1:VasTuHmOw+uD0oHCfApQcMO2+36SfyncoSahU7513Xs=
github.com/containers/libtrust v0.0.0-20190913040956-14b96171aa3b h1:Q8ePgVfHDplZ7U33NwHZkrVELsZP5fYj9pM5WBZB2GE=
diff --git a/vendor/github.com/containers/buildah/imagebuildah/build.go b/vendor/github.com/containers/buildah/imagebuildah/build.go
index 76796de72..bfbbb085d 100644
--- a/vendor/github.com/containers/buildah/imagebuildah/build.go
+++ b/vendor/github.com/containers/buildah/imagebuildah/build.go
@@ -133,7 +133,7 @@ func BuildDockerfiles(ctx context.Context, store storage.Store, options define.B
// pre-process Dockerfiles with ".in" suffix
if strings.HasSuffix(dfile, ".in") {
- pData, err := preprocessDockerfileContents(data, options.ContextDirectory)
+ pData, err := preprocessContainerfileContents(dfile, data, options.ContextDirectory)
if err != nil {
return "", nil, err
}
@@ -206,15 +206,15 @@ func warnOnUnsetBuildArgs(logger *logrus.Logger, node *parser.Node, args map[str
}
}
// preprocessDockerfileContents runs CPP(1) in preprocess-only mode on the input
// dockerfile content and will use ctxDir as the base include path.
//
// Note: we cannot use cmd.StdoutPipe() as cmd.Wait() closes it.
-func preprocessDockerfileContents(r io.Reader, ctxDir string) (rdrCloser *io.ReadCloser, err error) {
+func preprocessContainerfileContents(containerfile string, r io.Reader, ctxDir string) (rdrCloser *io.ReadCloser, err error) {
cppPath := "/usr/bin/cpp"
if _, err = os.Stat(cppPath); err != nil {
if os.IsNotExist(err) {
- err = errors.Errorf("error: Dockerfile.in support requires %s to be installed", cppPath)
+ err = errors.Errorf("error: %s support requires %s to be installed", containerfile, cppPath)
}
return nil, err
}
@@ -231,11 +231,7 @@ func preprocessDockerfileContents(r io.Reader, ctxDir string) (rdrCloser *io.Rea
return nil, err
}
- defer func() {
- if err != nil {
- pipe.Close()
- }
- }()
+ defer pipe.Close()
if err = cmd.Start(); err != nil {
return nil, err
@@ -247,10 +243,10 @@ func preprocessDockerfileContents(r io.Reader, ctxDir string) (rdrCloser *io.Rea
pipe.Close()
if err = cmd.Wait(); err != nil {
- if stderr.Len() > 0 {
- err = errors.Wrapf(err, "%v", strings.TrimSpace(stderr.String()))
+ if stdout.Len() == 0 {
+ return nil, errors.Wrapf(err, "error pre-processing Dockerfile")
}
- return nil, errors.Wrapf(err, "error pre-processing Dockerfile")
+ logrus.Warnf("Ignoring %s\n", stderr.String())
}
rc := ioutil.NopCloser(bytes.NewReader(stdout.Bytes()))
@@ -206,15 +206,15 @@ func warnOnUnsetBuildArgs(logger *logrus.Logger, node *parser.Node, args map[str
}
}
-// preprocessDockerfileContents runs CPP(1) in preprocess-only mode on the input
+// preprocessContainerfileContents runs CPP(1) in preprocess-only mode on the input
// dockerfile content and will use ctxDir as the base include path.
//